// src/index.tsx
import { useState, useEffect, useRef } from "react";
import * as pdfjs from "pdfjs-dist/legacy/build/pdf";
function isFunction(value) {
  return typeof value === "function";
}
var MAX_CANVAS_SIZE = 16777216;
var usePdf = ({
  canvasRef,
  file,
  onDocumentLoadSuccess,
  onDocumentLoadFail,
  onPageLoadSuccess,
  onPageLoadFail,
  onPageRenderSuccess,
  onPageRenderFail,
  scale = 1,
  rotate = 0,
  page = 1,
  cMapUrl,
  cMapPacked,
  workerSrc = `//cdnjs.cloudflare.com/ajax/libs/pdf.js/${pdfjs.version}/pdf.worker.js`,
  withCredentials = false
}) => {
  const [pdfDocument, setPdfDocument] = useState();
  const pdfPageRef = useRef();
  const renderTask = useRef(null);
  const onDocumentLoadSuccessRef = useRef(onDocumentLoadSuccess);
  const onDocumentLoadFailRef = useRef(onDocumentLoadFail);
  const onPageLoadSuccessRef = useRef(onPageLoadSuccess);
  const onPageLoadFailRef = useRef(onPageLoadFail);
  const onPageRenderSuccessRef = useRef(onPageRenderSuccess);
  const onPageRenderFailRef = useRef(onPageRenderFail);
  useEffect(() => {
    onDocumentLoadSuccessRef.current = onDocumentLoadSuccess;
  }, [onDocumentLoadSuccess]);
  useEffect(() => {
    onDocumentLoadFailRef.current = onDocumentLoadFail;
  }, [onDocumentLoadFail]);
  useEffect(() => {
    onPageLoadSuccessRef.current = onPageLoadSuccess;
  }, [onPageLoadSuccess]);
  useEffect(() => {
    onPageLoadFailRef.current = onPageLoadFail;
  }, [onPageLoadFail]);
  useEffect(() => {
    onPageRenderSuccessRef.current = onPageRenderSuccess;
  }, [onPageRenderSuccess]);
  useEffect(() => {
    onPageRenderFailRef.current = onPageRenderFail;
  }, [onPageRenderFail]);
  useEffect(() => {
    pdfjs.GlobalWorkerOptions.workerSrc = workerSrc;
  }, [workerSrc]);
  useEffect(() => {
    const config = { url: file, withCredentials };
    if (cMapUrl) {
      config.cMapUrl = cMapUrl;
      config.cMapPacked = cMapPacked;
    }
    pdfjs.getDocument(config).promise.then(
      (loadedPdfDocument) => {
        setPdfDocument(loadedPdfDocument);
        if (isFunction(onDocumentLoadSuccessRef.current)) {
          onDocumentLoadSuccessRef.current(loadedPdfDocument);
        }
      },
      () => {
        if (isFunction(onDocumentLoadFailRef.current)) {
          onDocumentLoadFailRef.current();
        }
      }
    );
  }, [file, withCredentials, cMapUrl, cMapPacked]);
  useEffect(() => {
    const drawPDF = (page2) => {
      const rotation = rotate === 0 ? page2.rotate : page2.rotate + rotate;
      let viewport = page2.getViewport({ scale, rotation });
      const dpr = window.devicePixelRatio;
      const dprWidth = viewport.width * dpr;
      const dprHeight = viewport.height * dpr;
      if (dprWidth * dprHeight > MAX_CANVAS_SIZE) {
        const aspectRatio = viewport.height / viewport.width;
        const maxWidth = Math.floor(Math.sqrt(MAX_CANVAS_SIZE / aspectRatio));
        const adjustedScale = maxWidth / dprWidth * scale;
        viewport = page2.getViewport({ scale: adjustedScale, rotation });
      }
      const canvasEl = canvasRef.current;
      if (!canvasEl) {
        return;
      }
      const canvasContext = canvasEl.getContext("2d");
      if (!canvasContext) {
        return;
      }
      canvasEl.height = viewport.height * dpr;
      canvasEl.width = viewport.width * dpr;
      canvasContext.scale(dpr, dpr);
      if (renderTask.current) {
        renderTask.current.cancel();
      }
      renderTask.current = page2.render({
        canvasContext,
        viewport
      });
      return renderTask.current.promise.then(
        () => {
          renderTask.current = null;
          if (isFunction(onPageRenderSuccessRef.current)) {
            onPageRenderSuccessRef.current(page2);
          }
        },
        (reason) => {
          if (reason && reason.name === "RenderingCancelledException")
            return;
          if (isFunction(onPageRenderFailRef.current)) {
            renderTask.current = null;
            onPageRenderFailRef.current();
          }
        }
      );
    };
    if (pdfDocument) {
      pdfDocument.getPage(page).then(
        (loadedPdfPage) => {
          pdfPageRef.current = loadedPdfPage;
          if (isFunction(onPageLoadSuccessRef.current)) {
            onPageLoadSuccessRef.current(loadedPdfPage);
          }
          drawPDF(loadedPdfPage);
        },
        () => {
          if (isFunction(onPageLoadFailRef.current)) {
            onPageLoadFailRef.current();
          }
        }
      );
    }
  }, [canvasRef, page, pdfDocument, rotate, scale]);
  return pdfDocument;
};
export {
  usePdf
};
